@@ -3,13 +3,13 @@ package Log::Saftpresse::Plugin::Postfix::QueueID;
 use Moose::Role;
 
 # ABSTRACT: plugin to parse the postfix queue ID
-our $VERSION = '1.2'; # VERSION
+our $VERSION = '1.3'; # VERSION
 
 sub process_queueid {
 	my ( $self, $stash ) = @_;
 	
 	if( my ( $queue_id, $msg ) = $stash->{'message'} =~
-			/^([A-Z0-9]{11}|[b-zB-Z0-9]{15}|NOQUEUE): (.+)$/) {
+			/^([A-Z0-9]{8,12}|[b-zB-Z0-9]{15}|NOQUEUE): (.+)$/) {
 		$stash->{'queue_id'} = $queue_id;
 		$stash->{'message'} = $msg;
 	}
@@ -31,7 +31,7 @@ Log::Saftpresse::Plugin::Postfix::QueueID - plugin to parse the postfix queue ID
 
 =head1 VERSION
 
-version 1.2
+version 1.3
 
 =head1 AUTHOR
 
